@@ -12,8 +12,10 @@ from Joking import Pun
 from Joking import yo_mama_joke_slash_insults
 from Joking import search_for_joke
 from Joking import JOD
-from Joking import chuck_norris_joke
+from Joking import chuck_norris_jokes
 from Joking import animal_joke
+from Joking import Irony_Joke
+from Joking import Irony_Joke_By_ID
 
 class TestSum(unittest.TestCase):
     def test_skkjoke(self):
@@ -77,7 +79,7 @@ Don't get too excited it's just a knock knock joke.
     def test_search_for_joke(self):
         data = "Monkey"
         result = search_for_joke(data)
-        self.assertNotEqual(result, "What do you call a monkey in a mine field? A babooooom!")
+        self.assertEqual(result, "\nWhat do you call a monkey in a mine field? A babooooom!\n\n")
 
 
     def test_JOD(self):
@@ -85,12 +87,19 @@ Don't get too excited it's just a knock knock joke.
         self.assertNotEqual(result, "Traceback (most recent call last):")
     
     def test_noris(self):
-        result = chuck_norris_joke()
+        result = chuck_norris_jokes()
         self.assertNotEqual(result, "Traceback (most recent call last):")
     
     def test_Animal_joke(self):
         result = animal_joke()
         self.assertNotEqual(result, "Traceback (most recent call last):")
-        
+    
+    def Irony(self):
+        result = Irony_Joke()
+        self.assertNotEqual(result, "Traceback (most recent call last):")
+    def Irony_By_ID(self):
+        result = Irony_Joke_By_ID(2)
+        self.assertEqual(result, "The irony of getting a job. You get a job so you won't be homeless. But when you get a job you're home a lot less.")
+
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
